$version = "v0.8 08-June-2015"

#  /********************************************************
# *                                                        *
# *   Copyright (c) Microsoft. All rights reserved.        *
# *                                                        *
# *********************************************************/



$Component = "PreSetup"

$tsenv = New-Object -COMObject Microsoft.SMS.TSEnvironment 

$logFile = "$($tsenv.Value('_SMSTSLogPath'))\$($Component).log"

$DataPath = "$env:SystemDrive\_vNextUpgrade"


Function Create-LogEntry {
	[CmdletBinding()]
	Param(
	  [Parameter(Mandatory=$True,ValueFromPipeline=$True,ValueFromPipelinebyPropertyName=$True)]
	  $sLogMsg
	)
PROCESS {
	# Populate the variables to log

	$sTime = (Get-Date -Format HH:mm:ss) + ".000+000"
	$sDate = Get-Date -Format MM-dd-yyyy
	$sTempMsg = "<![LOG[$sLogMsg]LOG]!><time=""$sTime"" date=""$sDate"" component=""$Component"" context="""" type="""" thread="""" file=""$Component"">"


	# Create the component log entry

	Write-Output $sTempMsg | Out-File -FilePath $logFile -Encoding "Default" -Append

}
} # End of Create-LogEntry function



Function Set-SchTask ( $task, $switch ) {
	#schtasks used for Windows 7 compatibility

	Create-LogEntry "Checking $task ..."
	$process = Start-Process -FilePath $env:WinDir\System32\schtasks.exe -ArgumentList "/query /tn `"$task`"" -Wait -NoNewWindow -PassThru -RedirectStandardOutput "$env:Temp\schtasks.out" -RedirectStandardError "$env:Temp\schtasks.err"
	If ( $process.ExitCode -eq 0 ) { 
		Create-LogEntry "$task exists, taking action $switch"
		schtasks /change /tn $task /$switch | Create-LogEntry 
	} Else { 
		Create-LogEntry "skipping $task, does not exist `(schtasks returned $($process.ExitCode)`)" 
	}


} # End of Set-SchTask function




# initialize log
Create-LogEntry "START $Component $version"


#Create-LogEntry "Windows PowerShell Version Check..."
#
#	$PSMinVer = 3.0
#
#	If ( Test-Path HKLM:\SOFTWARE\Microsoft\PowerShell\3\PowerShellEngine ) {
#		Create-LogEntry "PowerShell v3 key exists"
#		$PSVersion = (Get-ItemProperty -Path HKLM:\SOFTWARE\Microsoft\PowerShell\3\PowerShellEngine).PowerShellVersion
#		If ( $PSVersion -ge $PSMinVer ) { 
#			Create-LogEntry "PowerShell version $($PSVersion) or greater verified ok"
#		} Else {
#			Create-LogEntry "ERROR 2819: PowerShell is version $($PSVersion) which is less than minimum requirement of $($PSMinVer)"
#			Exit 2819
#		}
#	} Else {
#		Create-LogEntry "ERROR 9745: PowerShell version $($PSMinVer) is required."
#		Exit 9745
#	}


# Clear rollback condition trigger

	$trigger = "$DataPath\rollback"
	If ( Test-Path $trigger) {
		Create-LogEntry "Rollback condition trigger $trigger exists, deleting..."
		Remove-Item -Path $trigger -Force
	} 


Create-LogEntry "Set telemetry ID..."

	$regpath = "HKLM:\SYSTEM\Setup\MoSetup"
	$regval = "TestID"
	$regdata = "SCCMDEMO"

	If ( -NOT ( Test-Path $regpath ) ) {
		Create-LogEntry "$regpath does not exist"
		New-Item -Path $regpath -Force | Create-LogEntry
	} Else {
		Create-LogEntry "$regpath already exists"
	}

	New-ItemProperty -Path $regpath -Name $regval -Value $regdata -PropertyType String -Force | Create-LogEntry


Create-LogEntry "Enable Provisioning Mode"

	Invoke-WmiMethod -Namespace root\CCM -Class SMS_Client -Name SetClientProvisioningMode -ArgumentList $True
	Create-LogEntry "ProvisioningMode state: $((Get-ItemProperty -Path HKLM:\SOFTWARE\Microsoft\CCM\CcmExec).ProvisioningMode)"


Create-LogEntry "Fixing cache folder permissions..."

	icacls $tsenv.Value('_SMSTSMDataPath') /grant '"NT Service\TrustedInstaller":(OI)(CI)F' | Create-LogEntry
	icacls $tsenv.Value('_SMSTSMDataPath') | Create-LogEntry


Create-LogEntry "Create working directory $DataPath..."

	If ( Test-Path "$DataPath" ) {
		Create-LogEntry "$DataPath already exists"
	} Else {
		New-Item -Path $DataPath -ItemType Directory | Create-LogEntry
	}


Create-LogEntry "Disable CCMExec Service..."

	$service = Get-Service -Name "ccmexec"
	Set-Service -Name $service.Name -StartupType Disabled
	Create-LogEntry "$($service.DisplayName) is currently $($service.Status), start mode: $((gwmi -class win32_service -filter "name='$($service.Name)'").StartMode)"


Create-LogEntry "Disable Task Manager Service..."

	$service = Get-Service -Name "smstsmgr"
	Set-Service -Name $service.Name -StartupType Disabled
	Create-LogEntry "$($service.DisplayName) is currently $($service.Status), start mode: $((gwmi -class win32_service -filter "name='$($service.Name)'").StartMode)"


Create-LogEntry "Disable Health Tasks..."

	$action = "disable"
	Set-SchTask "\Microsoft\Configuration Manager\Configuration Manager Health Evaluation" $action
	Set-SchTask "\Microsoft\Configuration Manager\Configuration Manager Idle Detection" $action
	Set-SchTask "\Microsoft\Configuration Manager\Configuration Manager Maintenance" $action


Create-LogEntry "END"