$version = "v0.4 08-June-2015"

#  /********************************************************
# *                                                        *
# *   Copyright (c) Microsoft. All rights reserved.        *
# *                                                        *
# *********************************************************/


$Component = "RecoverSetup"

$tsenv = New-Object -COMObject Microsoft.SMS.TSEnvironment 

$logFile = "$($tsenv.Value('_SMSTSLogPath'))\$($Component).log"

$DataPath = "$env:SystemDrive\_vNextUpgrade"


Function Create-LogEntry {
	[CmdletBinding()]
	Param(
	  [Parameter(Mandatory=$True,ValueFromPipeline=$True,ValueFromPipelinebyPropertyName=$True)]
	  $sLogMsg
	)
PROCESS {
	# Populate the variables to log

	$sTime = (Get-Date -Format HH:mm:ss) + ".000+000"
	$sDate = Get-Date -Format MM-dd-yyyy
	$sTempMsg = "<![LOG[$sLogMsg]LOG]!><time=""$sTime"" date=""$sDate"" component=""$Component"" context="""" type="""" thread="""" file=""$Component"">"


	# Create the component log entry

	Write-Output $sTempMsg | Out-File -FilePath $logFile -Encoding "Default" -Append

}
} # End of Create-LogEntry function



Function Set-SchTask ( $task, $switch ) {
	#schtasks used for Windows 7 compatibility

	Create-LogEntry "Checking $task ..."
	$process = Start-Process -FilePath $env:WinDir\System32\schtasks.exe -ArgumentList "/query /tn `"$task`"" -Wait -NoNewWindow -PassThru -RedirectStandardOutput "$env:Temp\schtasks.out" -RedirectStandardError "$env:Temp\schtasks.err"
	If ( $process.ExitCode -eq 0 ) { 
		Create-LogEntry "$task exists, taking action $switch"
		schtasks /change /tn $task /$switch | Create-LogEntry 
	} Else { 
		Create-LogEntry "skipping $task, does not exist `(schtasks returned $($process.ExitCode)`)" 
	}


} # End of Set-SchTask function




# initialize log
Create-LogEntry "START $Component $version"


Create-LogEntry "Cleanup staged content..."

	Remove-Item -Path "$DataPath" -Force -Recurse


Create-LogEntry "Enable Health Tasks..."

	$action = "enable"
	Set-SchTask "\Microsoft\Configuration Manager\Configuration Manager Health Evaluation" $action
	Set-SchTask "\Microsoft\Configuration Manager\Configuration Manager Idle Detection" $action
	Set-SchTask "\Microsoft\Configuration Manager\Configuration Manager Maintenance" $action


Create-LogEntry "Enable CcmExec service..."

	$service = Get-Service -Name "ccmexec"
	Set-Service -Name $service.Name -StartupType Automatic
	Create-LogEntry "$($service.DisplayName) is currently $($service.Status), start mode: $((gwmi -class win32_service -filter "name='$($service.Name)'").StartMode)"


Create-LogEntry "Enable Task Manager Service..."

	$service = Get-Service -Name "smstsmgr"
	Set-Service -Name $service.Name -StartupType Automatic
	Create-LogEntry "$($service.DisplayName) is currently $($service.Status), start mode: $((gwmi -class win32_service -filter "name='$($service.Name)'").StartMode)"


Create-LogEntry "Disable Provisioning Mode..."

	Invoke-WmiMethod -Namespace root\CCM -Class SMS_Client -Name SetClientProvisioningMode -ArgumentList $False
	Create-LogEntry "ProvisioningMode state: $((Get-ItemProperty -Path HKLM:\SOFTWARE\Microsoft\CCM\CcmExec).ProvisioningMode)"


Create-LogEntry "END"


# Force task sequence failure

Exit 2648