$version = "v0.6 08-June-2015"

#  /********************************************************
# *                                                        *
# *   Copyright (c) Microsoft. All rights reserved.        *
# *                                                        *
# *********************************************************/


$Component = "SetupComplete"

# NOTE: the Microsoft.SMS.TSEnvironment COMObject can't be used because the task sequence is not running 

$logFile = "$($env:WinDir)\CCM\Logs\$($Component).log"

$DataPath = "$env:SystemDrive\_vNextUpgrade"


Function Create-LogEntry {
	[CmdletBinding()]
	Param(
	  [Parameter(Mandatory=$True,ValueFromPipeline=$True,ValueFromPipelinebyPropertyName=$True)]
	  $sLogMsg
	)
PROCESS {
	# Populate the variables to log

	$sTime = (Get-Date -Format HH:mm:ss) + ".000+000"
	$sDate = Get-Date -Format MM-dd-yyyy
	$sTempMsg = "<![LOG[$sLogMsg]LOG]!><time=""$sTime"" date=""$sDate"" component=""$Component"" context="""" type="""" thread="""" file=""$Component"">"


	# Create the component log entry

	Write-Output $sTempMsg | Out-File -FilePath $logFile -Encoding "Default" -Append

}
} # End of Create-LogEntry function



Function Set-SchTask ( $task, $switch ) {
	#schtasks used for Windows 7 compatibility

	Create-LogEntry "Checking $task ..."
	$process = Start-Process -FilePath $env:WinDir\System32\schtasks.exe -ArgumentList "/query /tn `"$task`"" -Wait -NoNewWindow -PassThru -RedirectStandardOutput "$env:Temp\schtasks.out" -RedirectStandardError "$env:Temp\schtasks.err"
	If ( $process.ExitCode -eq 0 ) { 
		Create-LogEntry "$task exists, taking action $switch"
		schtasks /change /tn $task /$switch | Create-LogEntry 
	} Else { 
		Create-LogEntry "skipping $task, does not exist `(schtasks returned $($process.ExitCode)`)" 
	}


} # End of Set-SchTask function




# initialize log
Create-LogEntry "START $Component $version"


Create-LogEntry "CCMREPAIR..."

	$process = Start-Process $env:WinDir\ccmsetup\ccmsetup.exe -ArgumentList "/remediate:client" -Wait -NoNewWindow -PassThru

	# Create-LogEntry "Return code: $($process.ExitCode)"
	If ( $process.ExitCode -eq 0 ) { 
		Create-LogEntry "Client Setup Complete successfully with $($process.ExitCode)"
       	   
        Create-LogEntry "Start Task Manager Service..."

	    $service = Get-Service -Name "smstsmgr"
	    Set-Service -Name $service.Name -StartupType Automatic
	    Start-Service -Name $service.Name
	    Create-LogEntry "$($service.DisplayName) is currently $($service.Status), start mode: $((gwmi -class win32_service -filter "name='$($service.Name)'").StartMode)"

	    Create-LogEntry "Wait for Task Manager Service..."
        $service.WaitForStatus("Stopped")
	
	} 
    ElseIf ( $process.ExitCode -eq 1 ) { 
		Create-LogEntry "Client Setup Completed with 'Error' $($process.ExitCode ) see CCMSetup.log for more information" Else } 
    ElseIf ( $process.ExitCode -eq 2 ) { 
		Create-LogEntry "Client Setup Completed with 'Reboot Required' $($process.ExitCode) see CCMSetup.log for more information" Else } 
    ElseIf ( $process.ExitCode -eq 3 ) { 
		Create-LogEntry "Client Setup Completed with 'Already Running' $($process.ExitCode) see CCMSetup.log for more information" Else } 
    ElseIf ( $process.ExitCode -eq 4 ) { 
		Create-LogEntry "Client Setup Completed with 'Evaluate Fail' $($process.ExitCode) see CCMSetup.log for more information" Else }  
    ElseIf ( $process.ExitCode -eq 5 ) {
		Create-LogEntry "Client Setup Completed with 'Manifest Hash Validation Fail' $($process.ExitCode) see CCMSetup.log for more information" Else }  
    Else { 
		Create-LogEntry "Setup Completed with $($process.ExitCode) see CCMSetup.log for more information)"
	
	}



Create-LogEntry "Enable Health Tasks..."

	$action = "enable"
	Set-SchTask "\Microsoft\Configuration Manager\Configuration Manager Health Evaluation" $action
	Set-SchTask "\Microsoft\Configuration Manager\Configuration Manager Idle Detection" $action
	Set-SchTask "\Microsoft\Configuration Manager\Configuration Manager Maintenance" $action


Create-LogEntry "Disable Provisioning Mode..."

	Invoke-WmiMethod -Namespace root\CCM -Class SMS_Client -Name SetClientProvisioningMode -ArgumentList $False
	Create-LogEntry "ProvisioningMode state: $((Get-ItemProperty -Path HKLM:\SOFTWARE\Microsoft\CCM\CcmExec).ProvisioningMode)"


Create-LogEntry "END"